newInscription{
	name = "Infusion: Mindhook",
	type = {"inscriptions/infusions", 1},
	points = 1,
	tactical = { CLOSEIN = 2 },
	range = function(self, t)
		local data = self:getInscriptionData(t.short_name)
		return data.range
	end,
	action = function(self, t)
		local tg = {type="bolt", range=self:getTalentRange(t)}
		local x, y = self:getTarget(tg)
		if not x or not y then return nil end
		local _ _, x, y = self:canProject(tg, x, y)
		local target = game.level.map(x, y, engine.Map.ACTOR)
		if not target then
			game.logPlayer(self, "The target is out of range")
			return
		end
		target:pull(self.x, self.y, tg.range)
		target:setEffect(target.EFF_DAZED, 1, {})
		game:playSoundNear(self, "talents/arcane")

		return true
	end,
	info = function(self, t)
		local data = self:getInscriptionData(t.short_name)
		return ([[Activate the infusion to grab an enemy from %d tiles away.]]):format(data.range + data.inc_stat)
	end,
	short_info = function(self, t)
		local data = self:getInscriptionData(t.short_name)
		return ([[range %d]]):format(data.range + data.inc_stat)
	end,
}

newInscription{
	name = "Infusion: Quickness",
	type = {"inscriptions/infusions", 1},
	points = 1,
	no_energy = true,
	tactical = { CLOSEIN = 1, ESCAPE = 1 },
	action = function(self, t)
		local data = self:getInscriptionData(t.short_name)
		game:onTickEnd(function() self:setEffect(self.EFF_QUICKNESS, data.dur, {power=(data.speed + data.inc_stat) / 100}) end)
		return true
	end,
	info = function(self, t)
		local data = self:getInscriptionData(t.short_name)
		return ([[Activate the infusion to increase movement speed by %0.2f%% for %d game turns.
		Note: since you will be moving fast, game turns will pass slowly.]]):format(data.speed + data.inc_stat, data.dur)
	end,
	short_info = function(self, t)
		local data = self:getInscriptionData(t.short_name)
		return ([[%d%% speed; %d turns]]):format(data.speed + data.inc_stat, data.dur)
	end,
}

newInscription{
	name = "Infusion: Sensing",
	type = {"inscriptions/infusions", 1},
	points = 1,
	no_npc_use = true,
	action = function(self, t)
		local data = self:getInscriptionData(t.short_name)
		self:setEffect(self.EFF_SENSE, data.dur, {
			range = data.rad,
			actor = 1,
		})
		return true
	end,
	info = function(self, t)
		local data = self:getInscriptionData(t.short_name)
		return ([[Activate the infusion to sense enemies within %d tiles for %d turns.]]):format(data.rad + data.inc_stat, data.dur)
	end,
	short_info = function(self, t)
		local data = self:getInscriptionData(t.short_name)
		return ([[radius %d for %d turns]]):format(data.rad + data.inc_stat, data.dur)
	end,
}

newInscription{
	name = "Infusion: Leap",
	type = {"inscriptions/infusions", 1},
	points = 1,
	tactical = { CLOSEIN = 2, ESCAPE = 2 },
	range = function(self, t)
		local data = self:getInscriptionData(t.short_name)
		return data.range
	end,
	requires_target = true,
	target = function(self, t)
		return {type="hit", range=self:getTalentRange(t)}
	end,
	direct_hit = true,
	action = function(self, t)
		local tg = self:getTalentTarget(t)
		local x, y = self:getTarget(tg)
		if not x or not y then return nil end
		if not self:hasLOS(x, y) then
			game.logSeen(self, "You do not have line of sight.")
			return nil
		end

		game.level.map:particleEmitter(self.x, self.y, 1, "temporal_teleport")

		-- since we're using a precise teleport we'll look for a free grid first
		local tx, ty = util.findFreeGrid(x, y, 5, true, {[Map.ACTOR]=true})
		if tx and ty then
			if not self:teleportRandom(tx, ty, 0) then
				game.logSeen(self, "The leap fails!")
			end
		end

		game.level.map:particleEmitter(self.x, self.y, 1, "temporal_teleport")
		game:playSoundNear(self, "talents/teleport")

		return true
	end,
	info = function(self, t)
		local data = self:getInscriptionData(t.short_name)
		return ([[Leap to a location in line of sight, up to %d tiles away.]]):format(data.range + data.inc_stat)
	end,
	short_info = function(self, t)
		local data = self:getInscriptionData(t.short_name)
		return ([[range %d]]):format(data.range + data.inc_stat)
	end,
}
